@@ -9,7 +9,9 @@ NMreadSimRes <- function(x){
 
     
     res.list <- lapply(x,NMreadSimResOne)
-    res <- rbindlist(res.list,fill=TRUE)
+    ## res <- rbindlist(res.list,fill=TRUE)
+
+    res <- do.call(rbind,c(res.list,fill=TRUE))
 
     addClass(res,"NMsimRes")
     res
