@@ -14,10 +14,23 @@ NMdataConf(reset=TRUE)
 ### dir.sims may be different in these tests than in other test
 ### scripts. The reason is the control streams are the outputs to be
 ### compared.
+
+path.candidates <- c(## metworx
+    "/opt/NONMEM/nm75/run/nmfe75"
+    ## custom linux
+   ,"/opt/nonmem/nm751/run/nmfe75"
+    ## a win path
+   ,"c:/nm75g64/run/nmfe75.bat"
+)
+
+
+(path.nonmem <- NMsim:::prioritizePaths(path.candidates))
+
 NMdataConf(
     dir.sims="testOutput"
     ## dir.sims="testOutput/simtmp"
     ##   ,dir.res="testOutput/simres"
+    ,path.nonmem=path.nonmem
 )
 
 
@@ -25,20 +38,19 @@ NMdataConf(
 
 dt.amt <- data.table(DOSE=c(100,400))
 dt.amt[,AMT:=DOSE*1000]
-dt.amt
 doses.sd <- NMcreateDoses(TIME=0,AMT=dt.amt,as.fun="data.table")
 doses.sd[,dose:=paste(DOSE,"mg")]
 doses.sd[,regimen:="SD"]
 
 
-dat.sim.sd <- addEVID2(doses.sd,time.sim=0:24,CMT=2,as.fun="data.table")
+dat.sim.sd <- NMaddSamples(doses.sd,TIME=0:24,CMT=2,as.fun="data.table")
 dat.sim <- copy(dat.sim.sd)
 
 ## NMcheckData(dat.sim)
 
 dat.sim[,ROW:=.I]
 
-head(dat.sim)
+##head(dat.sim)
 
 dat.sim[,BBW:=75]
 
@@ -61,7 +73,7 @@ test_that("NMsim_NWPRI",{
     
 
     ## ref <- readRDS(fileRef)
-    if(packageVersion("NMdata")>="2.1.0"){
+    if(packageVersion("NMdata")>="0.2.1"){
         expect_equal_to_reference(mod$THETAPV,fnAppend(fileRef,"THETAPV"))
         expect_equal_to_reference(mod$OMEGAP,fnAppend(fileRef,"OMEGAP"))
         expect_equal_to_reference(mod,fileRef)
@@ -99,75 +111,130 @@ test_that("NMsim_NWPRI",{
 })
 
 ## block OMEGA 4x4
-## will fail if NMdata version < 0.1.8.905 due to NMupdateSizes
-if(packageVersion("NMdata") >= "0.1.8.904") {
+test_that("NMsim_NWPRI_Omega44",{
     
-    test_that("NMsim_NWPRI_Omega44",{
-        
-        fileRef <- "testReference/NMsim_NWPRI_02.rds"
-        
-        file.mod <- "testData/nonmem/predu.ctl"
-        dat.sim <- fread("testData/nonmem/example1.csv",skip = 1)
-        
-        sim1 <- NMsim(file.mod=file.mod,
-                      data=dat.sim,
-                      name.sim = "sd2_NWPRI",
-                      method.sim=NMsim_NWPRI,
-                      seed.nm=2342,
-                      execute=FALSE,
-                      method.update.inits="nmsim")
-        
-        mod <- NMreadSection("testOutput/predu_sd2_NWPRI/predu_sd2_NWPRI.mod")
-        
-        
-        ## ref <- readRDS(fileRef)
-        expect_equal_to_reference(mod$THETAPV,fnAppend(fileRef,"THETAPV"))
-        expect_equal_to_reference(mod$OMEGAP,fnAppend(fileRef,"OMEGAP"))
+    fileRef <- "testReference/NMsim_NWPRI_02.rds"
+    
+    file.mod <- "testData/nonmem/predu.ctl"
+    dat.sim <- fread("testData/nonmem/example1.csv",skip = 1)
+    
+    sim1 <- NMsim(file.mod=file.mod,
+                  data=dat.sim,
+                  name.sim = "sd2_NWPRI",
+                  method.sim=NMsim_NWPRI,
+                  seed.nm=2342,
+                  execute=FALSE,
+                  method.update.inits="nmsim")
+    
+    mod <- NMreadSection("testOutput/predu_sd2_NWPRI/predu_sd2_NWPRI.mod")
+    
+    
+    ## ref <- readRDS(fileRef)
+    expect_equal_to_reference(mod$THETAPV,fnAppend(fileRef,"THETAPV"))
+    expect_equal_to_reference(mod$OMEGAP,fnAppend(fileRef,"OMEGAP"))
 ### expect_equal_to_reference(mod,fileRef) failed on cran, not on github. I don't know why. It may be an extra space somewhere.
-        ## expect_equal_to_reference(mod,fileRef)
-        ## expect_equal_to_reference(mod[c("THETA","OMEGA","SIGMA","PRIOR","THETAP","OMEGAPD","SIGMAP","SIGMAPD")],fileRef)
-        ## mod.clean <- lapply(mod,NMdata:::cleanSpaces)
-        ## mod.clean$INPUT <- paste(mod.clean$INPUT,collapse=" ")
+    ## expect_equal_to_reference(mod,fileRef)
+    ## expect_equal_to_reference(mod[c("THETA","OMEGA","SIGMA","PRIOR","THETAP","OMEGAPD","SIGMAP","SIGMAPD")],fileRef)
+    ## mod.clean <- lapply(mod,NMdata:::cleanSpaces)
+    ## mod.clean$INPUT <- paste(mod.clean$INPUT,collapse=" ")
 ### CRAN say INPUT has changed. I can't figure out why for now. Could it be that dat.sim is different on CRAN? Or is something messing up because of the comment in first line of the data file?
-        mod$INPUT <- NULL
+    mod$INPUT <- NULL
 
-        expect_equal_to_reference(mod,fileRef)
+    expect_equal_to_reference(mod,fileRef)
 
-        if(F){
-            ref <- readRDS(fileRef)
-            ref$OMEGA
-            mod$OMEGA 
-            ref$SIGMA
-            mod$SIGMA
-            ref$SIMULATION
-            mod$SIMULATION
-            
-            compareCols(ref,mod)
-            
-            ref$OMEGAP
-            mod$OMEGAP
-            
-            ref$THETAPV
-            mod$THETAPV
-
-            ref$INPUT
-            mod$INPUT
-
-            ref$DATA
-            mod$DATA
-
-            ref$TABLE
-            mod$TABLE
-
-
-        }
+    if(F){
+        ref <- readRDS(fileRef)
+        ref$OMEGA
+        mod$OMEGA 
+        ref$SIGMA
+        mod$SIGMA
+        ref$SIMULATION
+        mod$SIMULATION
         
+        compareCols(ref,mod)
         
-    })
+        ref$OMEGAP
+        mod$OMEGAP
+        
+        ref$THETAPV
+        mod$THETAPV
+
+        ref$INPUT
+        mod$INPUT
+
+        ref$DATA
+        mod$DATA
+
+        ref$TABLE
+        mod$TABLE
+
+
+    }
+    
+})
+
+
+## block omega 2x2 mixed with other non block omegas
+## xgxr033.mod
+
+
+test_that("block OMEGA 4x4 - typical",{
+    
+    fileRef <- "testReference/NMsim_NWPRI_03.rds"
+    
+    file.mod <- "testData/nonmem/predu.ctl"
+    dat.sim <- fread("testData/nonmem/example1.csv",skip = 1)
+    
+    sim1 <- NMsim(file.mod=file.mod,
+                  data=dat.sim,
+                  name.sim = "sd3_NWPRI",
+                  method.sim=NMsim_NWPRI,
+                  seed.nm=2342,
+                  execute=FALSE,
+                  typical=TRUE)
+    
+    mod <- NMreadSection("testOutput/predu_sd3_NWPRI/predu_sd3_NWPRI.mod")
+    
+    ## ref <- readRDS(fileRef)
+    ## expect_equal_to_reference(mod$THETAPV,fnAppend(fileRef,"THETAPV"))
+    expect_equal_to_reference(mod$OMEGAP,fnAppend(fileRef,"OMEGAP"))
+    expect_equal_to_reference(mod$OMEGAPD,fnAppend(fileRef,"OMEGAPD"))
+
+    mod$INPUT <- NULL
+
+    expect_equal_to_reference(mod,fileRef)
+
+    if(F){
+        ref <- readRDS(fileRef)
+        ref$OMEGA
+        mod$OMEGA 
+        ref$SIGMA
+        mod$SIGMA
+        ref$SIMULATION
+        mod$SIMULATION
+        
+        compareCols(ref,mod)
+        
+        ref$OMEGAP
+        mod$OMEGAP
+
+        ref$OMEGAPD
+        mod$OMEGAPD
+        
+        ref$THETAPV
+        mod$THETAPV
+
+        ref$INPUT
+        mod$INPUT
+
+        ref$DATA
+        mod$DATA
+
+        ref$TABLE
+        mod$TABLE
+
+
+    }
     
     
-}
-
-
-                                        # block omega 2x2 mixed with other non block omegas
-                                        # xgxr033.mod
+})
