@@ -96,7 +96,9 @@ test_that("time with covariates",{
     seq.time.md <- data.table(regimen="MD",TIME=c(0,4,12,24))
     seq.time <- rbind(seq.time.sd,seq.time.md)
     
-    res <- addEVID2(dt.doses,time.sim=seq.time,CMT=2)
+    res <- expect_message(
+        addEVID2(dt.doses,time.sim=seq.time,CMT=2)
+        )
 
     ## dt.doses
     ## res
@@ -314,14 +316,22 @@ test_that("Unmatched covariates",{
     samp.times <- c(1, 4, 8)
     dt.dos <- NMsim::NMcreateDoses(TIME=data.frame(TIME=0, TSTRAT=0, TMIN=0, TMAX=200),AMT=70,CMT=NA)
 
+    TIME <- data.frame(TIME=c(1,4,8), TSTRAT=seq(1:length(samp.times)), 
+                       TMIN=rep(0.01,length(samp.times)),
+                       TMAX=rep(200,length(samp.times)))
+
+    dt.dos
+    TIME
+
     res <- expect_message(
-        NMsim::addEVID2(dt.dos,TIME = data.frame(TIME=c(1,4,8), TSTRAT=seq(1:length(samp.times)), 
-                                                 TMIN=rep(0.01,length(samp.times)),
-                                                 TMAX=rep(200,length(samp.times))))
+        addEVID2(dt.dos,TIME)
     )
 
-
     expect_equal_to_reference(res,fileRef)
+
+    if(F){
+        readRDS(fileRef)
+    }
     
 })
 
@@ -344,6 +354,10 @@ test_that("Unmatched covariates",{
 
 
     expect_equal_to_reference(res,fileRef)
+
+    if(F){
+        readRDS(fileRef)
+    }
     
 })
 
@@ -355,10 +369,10 @@ test_that("Unmatched are not covs",{
     dt.dos <- NMsim::NMcreateDoses(TIME=data.frame(TIME=0, TSTRAT=0, TMIN=0, TMAX=200),AMT=70,CMT=NA)
     dt.time <- data.frame(TIME=c(1,4,8), TSTRAT=c(1,2,3))
     
-    res <- NMsim::addEVID2(dt.dos,
+    res <- expect_message(NMsim::addEVID2(dt.dos,
                            TIME =dt.time
-                          ,
-                           extras.are.covs=FALSE)
+                          ,extras.are.covs=FALSE))
+
 
     ## res
     expect_equal_to_reference(res,fileRef)
